<?php

namespace Drupal\beehotel_addtocart;

// https://metadrop.net/en/articles/drupal-8-commerce-2-create-order-programmatically
use Drupal\commerce_cart\CartManagerInterface;
use Drupal\commerce_cart\CartProviderInterface;
use Drupal\commerce_price\Price;
use Drupal\commerce_product\Entity\Product;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\node\Entity\Node;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Add to Cart  features for BEE HOTEL.
 */
class AddToCart {

  /**
   * The order item storage.
   *
   * @var \Drupal\commerce_order\OrderItemStorageInterface
   */
  protected $orderItemStorage;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The cart manager.
   *
   * @var \Drupal\commerce_cart\CartManagerInterface
   */
  protected $cartManager;

  /**
   * The cart provider.
   *
   * @var \Drupal\commerce_cart\CartProviderInterface
   */
  protected $cartProvider;

  /**
   * Constructs a new AddReservationForm object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\commerce_cart\CartManagerInterface|null $cart_manager
   *   The cart manager.
   * @param \Drupal\commerce_cart\CartProviderInterface|null $cart_provider
   *   The cart provider.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, ConfigFactoryInterface $config_factory, ?CartManagerInterface $cart_manager, ?CartProviderInterface $cart_provider) {
    if ($entity_type_manager->hasHandler('commerce_order_item', 'storage')) {
      $this->orderItemStorage = $entity_type_manager->getStorage('commerce_order_item');
    }
    $this->configFactory = $config_factory;
    $this->cartManager = $cart_manager;
    $this->cartProvider = $cart_provider;
  }

  /**
   * We dont know this method is being used?
   */
  public function add($data) {

    dump("yes, we are using this");

    $node = Node::load($data['nid']);

    $bee_settings = \Drupal::config('node.type.' . $node->bundle())->get('bee');

    if ($bee_settings['bookable_type'] == 'daily') {
      $checkin = new \DateTime($data['checkin']);
      $checkout = new \DateTime($data['checkout']);
    }
    else {
      $checkin = new \DateTime($data['checkin']->format('Y-m-d H:i'));
      $checkout = new \DateTime($data['checkout']->format('Y-m-d H:i'));
    }

    if ($bee_settings['payment']) {
      $booking = bat_booking_create([
        'type' => 'bee',
        'label' => $node->label(),
      ]);
      $booking->set('booking_start_date', $checkin->format('Y-m-d\TH:i:s'));
      $booking->set('booking_end_date', $checkout->format('Y-m-d\TH:i:s'));
      $booking->save();

      /*Load Product*/
      $product = Product::load((int) $data['pid']);

      /* dump ($product);exit; */
      $stores = $product->getStores();
      $store = reset($stores);

      /*Load Product Variations*/
      $variations = $product->getVariationIds();

      foreach ($variations as $v) {
        $product_variation = \Drupal::entityTypeManager()->getStorage('commerce_product_variation')->load((int) $v);
        $sku = $product_variation->get('sku')->get(0)->value;

        // 0
        // dump ("sku");
        // dump ($sku);exit;
        // .
        $my_variation = [];
        if ($sku == $data['guests']) {
          $my_variation['title'] = $product_variation->get('title')->get(0)->value;
          $my_variation['variant_id'] = $product_variation->get('variation_id')->get(0)->value;

          if (isset($data['total']) && $data['total'] > 0) {
            $my_variation['price'] = new Price($data['total'], 'EUR');
          }
          else {
            $my_variation['price'] = $product_variation->getPrice();
          }
          break;
        }
      }

      // Nights.
      $minutes = ($checkout->getTimestamp() - $checkin->getTimestamp()) / 60;
      $hours = $minutes / 60;
      $data['nights'] = $hours / 24;

      // 0
      // dump(__FUNCTION__);
      // dump ($data);
      // dump ("my variation");
      // dump ($my_variation);exit;
      // .
      $cart_manager  = \Drupal::service('commerce_cart.cart_manager');
      $cart_provider = \Drupal::service('commerce_cart.cart_provider');

      // @todo check "default" cart exists.
      $cart = $cart_provider->getCart('default', $store);
      // 0
      // dump ($cart);exit;
      // .
      if (!$cart) {
        $cart = $cart_provider->createCart('default', $store);
      }
      else {
        $cart_manager->emptyCart($cart);
      }

      $order_item = \Drupal::entityTypeManager()->getStorage('commerce_order_item')->create([
        'title'            => $node->label(),
        'type'             => 'bee',
        'purchased_entity' => $my_variation['variant_id'],
        'quantity'         => $data['nights'],
        'unit_price'       => $my_variation['price'],
        'total_price'      => $my_variation['price'],
      ]);

      $order_item->set('field_booking', $booking);
      $order_item->set('field_node', $node);
      $order_item->set('field_check_in', [$checkin->format('Y-m-d\TH:i:s')]);
      $order_item->set('field_check_out', [$checkout->format('Y-m-d\TH:i:s')]);
      $order_item->set('field_nights', [$data['nights']]);
      $order_item->save();

      if (isset($data['total']) && $data['total'] > 0) {
        $session = \Drupal::request()->getSession();
        $session->set('beehotel_addtocart_unitprice', $data['total']);
      }

      $cart_manager->addOrderItem($cart, $order_item);
      $url = "/cart";
      $response = new RedirectResponse($url);
      $response->send();

    }
    exit;

  }

}
