<?php

namespace Drupal\beehotel_pricealterator\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\NodeInterface;
use Drupal\node\Entity\Node;

/**
 * Provide a table form for the base price.
 */
class UnitBasePriceTable extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bee_hotel_unit_base_price_table_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, NodeInterface $node = NULL) {

    $data = [];
    $config = \Drupal::config('beehotel_pricealterator.settings');
    $util = \Drupal::service('beehotel_pricealterator.util');
    $data['days'] = $util->days();

    $entity_manager = \Drupal::entityTypeManager();
    $data['tmp'] = $node->get('field_product')->getValue()[0]['target_id'];
    $data['product'] = $entity_manager->getStorage('commerce_product')->load($data['tmp']);
    $data['tmp'] = $data['product']->getStores();
    $data['store'] = reset($data['tmp']);
    $data['currency_code'] = $data['store']->get('default_currency')->getValue()[0]['target_id'];

    $form['node'] = [
      '#type' => 'hidden',
      '#value' => $node->id(),
    ];

    // Add the headers.
    $form['basepricetable'] = [
      '#type' => 'table',
      '#title' => t('Unit base price table'),
      '#header' => [t('Day'), t('Low season'), t('High season')],
      '#prefix' => t("This table contains base prices for a given unit, a given day, a given season. If no price alterator is active, Bee Hotel offers to Guest price here exposed."),
    ];

    foreach ($data['days'] as $code => $label) {
      $form['basepricetable'][$code]['label'] = [
        '#type' => 'label',
        '#title' => $label,
        '#description' => t('Base price per unit per night per 1 person. Use price_alterators to increase prise when request is for more than 1 person.'),
      ];

      $form['basepricetable'][$code]['high'] = [
        '#default_value' => $config->get($node->id() . "_" . $code . "_high"),
        '#min' => 0.01,
        '#required' => TRUE,
        '#step' => 0.01,
        '#suffix' => $data['currency_code'],
        '#title' => $label,
        '#title_display' => 'invisible',
        '#type' => 'number',

      ];

      $form['basepricetable'][$code]['low'] = [
        '#default_value' => $config->get($node->id() . "_" . $code . "_low"),
        '#min' => 0.01,
        '#required' => TRUE,
        '#step' => 0.01,
        '#suffix' => $data['currency_code'],
        '#title' => $label,
        '#title_display' => 'invisible',
        '#type' => 'number',
      ];
    }

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => t('Update'),
    ];

    $form['#attached']['library'][] = 'beehotel_pricealterator/unitbasepricetable';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::service('config.factory')->getEditable('beehotel_pricealterator.settings');
    $values = $form_state->getValues();
    $node = Node::load($values['node']);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = \Drupal::service('config.factory')->getEditable('beehotel_pricealterator.settings');
    $values = $form_state->getValues();
    foreach ($values['basepricetable'] as $day => $val) {
      foreach ($val as $sea => $pri) {
        $config->set($values['node'] . "_" . $day . "_" . $sea, $pri)->save();
      }
    }
  }

}
