<?php

namespace Drupal\beehotel_pricealterators\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Occupants Alterator.
 */
class Occupants extends ConfigFormBase {

  /**
   * Constructs a new alterator object.
   */
  public function __construct() {
    $config = \Drupal::config($this->configName());
    $this->status = $config->get('status');
    $this->increase = $config->get('increase');
  }

  /**
   * Reference to the Alterator (as plugin).
   *
   *   This value matches the ID in the @PriceAlterator annotation.
   */
  public function pluginId() {
    return 'Occupants';
  }

  /**
   * {@inheritdoc}
   */
  public function configName() {
    return 'beehotel_pricealterators.' . $this->pluginId() . '.settings';
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return $this->configName();
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      $this->configName(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config($this->configName());

    $form = [
      '#type' => 'fieldset',
      '#title' => $this->t('Occupants alterator'),
      '#collapsible' => FALSE,
    ];

    $form['status'] = [
      '#default_value' => $config->get('status'),
      '#type' => 'checkbox',
      '#title' => $this->t('Enable this alterator'),
      '#description' => $this->t('When on, this alterator will be applied the BEEHotel prices'),
    ];

    for ($i = 1; $i <= 4; $i++) {

      $title = $this->formatPlural($i, '1 occupant.', '@count occupants.');
      $description = $this->formatPlural($i, 'Percentage alteration for 1 occupant.', 'Percentage alteration for @count occupants.');

      $form['increase'][$i] = [
        '#default_value' => $config->get('increase_' . $i),
        '#type' => 'range_slider',
        '#title' => $title,
        '#min' => -100,
        '#max' => 100,
        '#step' => 1,
        '#description' => $description,
        '#data-orientation' => 'horizontal',
        '#output' => 'below',
        '#output__field_prefix' => '',
        '#output__field_suffix' => '%',
      ];
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->config($this->configName())
      ->set('status', $form_state->getValue('status'))
      ->set('increase_1', $form_state->getValue('1'))
      ->set('increase_2', $form_state->getValue('2'))
      ->set('increase_3', $form_state->getValue('3'))
      ->set('increase_4', $form_state->getValue('4'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
