<?php

namespace Drupal\bee_hotel\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\node\Entity\Node;

/**
 * Validate access to the unti entity.
 *
 * @package Drupal\bee_hotel
 */
class BeeHotelBookThisUnitAccessCheck implements AccessInterface {

  /**
   * The entity manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a BeeHotelBookThisUnitAccessCheck object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_manager
   *   The entity manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_manager) {
    $this->entityTypeManager = $entity_manager;
  }

  /**
   * Check access to the unit entity.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The currently logged in account.
   * @param \Drupal\node\Entity\Node $node
   *   A unit node.
   *
   * @return string
   *   A \Drupal\Core\Access\AccessInterface constant value.
   */
  public function access(AccountInterface $account, Node $node = NULL) {

    // 0
    // echo "anon can't book";
    // dump ($node);exit;
    // .
    if ($node) {
      $bee_hotel_settings = \Drupal::config('node.type.' . $node->bundle())->get('bee');
      // 0
      // dump ($bee_hotel_settings);exit;
      // .
      if (isset($bee_hotel_settings['bookable']) && $bee_hotel_settings['bookable']) {

        // Everybody is welcome to book my units :)
        return AccessResult::allowed();

      }
    }
    return AccessResult::forbidden();
  }

}
