<?php

namespace Drupal\bee_hotel\Resolvers;

use Drupal\bee_hotel\Util\Dates;
use Drupal\commerce\Context;
use Drupal\commerce\PurchasableEntityInterface;
use Drupal\commerce_price\Price;
use Drupal\commerce_price\Resolver\PriceResolverInterface;

/**
 * Interacts with Commerce price system.
 *
 * @package Drupal\bee_hotel\Resolvers
 */
class SalepriceResolver implements PriceResolverInterface {

  /**
   * The dates Utilities.
   *
   * @var Object
   */
  protected $datesUtil;

  /**
   * Constructs the object.
   */
  public function __construct() {
    $this->datesUtil = new Dates($data = []);
  }

  /**
   * {@inheritdoc}
   */
  public function resolve(PurchasableEntityInterface $entity, $quantity, Context $context) {

    if ($entity->bundle() != 'bee') {
      return;
    }

    $cart_provider = \Drupal::service('commerce_cart.cart_provider');
    $stores = $entity->getProduct()->getStores();
    $store = reset($stores);
    $currency_code = $store->get('default_currency')->getValue()[0]['target_id'];

    if (!empty($_REQUEST['dates'])) {
      $data = [];
      $data['values']['dates'] = $_REQUEST['dates'];
      $this->datesUtil->normaliseDatesFromSearchForm($data);
      $dates = $data['norm']['dates_from_search_form'];
      if (isset($dates['checkin']) && isset($dates['checkout']) && $_REQUEST['guests']) {
        if ($_REQUEST['form_id'] == "bee_hotel_book_this_unit_form") {
          $this->fromSingleForm($data, $context, $entity);
        }
        elseif ($_REQUEST['form_id'] == "beehotel_units_search") {
          $this->fromUnitsSearchForm($data, $context, $entity);
        }
        else {
          return;
        }

        $data['amount'] = bee_hotel_number_format($data['amount']);
        $price = new Price($data['amount'], $currency_code);
        return $price;
      }
    }
  }

  /**
   * Get useful data.
   */
  private function fromSingleForm(&$data, $context, $entity) {

    $data['adults'] = (int) $_REQUEST['guests'];
    $data['context'] = $context;
    $data['date'] = time();
    $data['entity'] = $entity;

    $beehotelunit = \Drupal::service('bee_hotel.util.beehotelunit');

    $data['node'] = $beehotelunit->getVariationNode($entity);
    $data['nid'] = $data['node']->Id();
    $data['season'] = \Drupal::service('beehotel_pricealterator.prealter')->season($data);
    $data = \Drupal::service('beehotel_pricealterator.alter')->alter($data);
  }

  /**
   * Get useful data.
   */
  private function fromUnitsSearchForm(&$data, $context, $entity) {
    $data['adults'] = $_REQUEST['guests'];
    $data['context'] = $context;
    $data['date'] = time();
    $data['entity'] = $entity;

    $beehotelunit = \Drupal::service('bee_hotel.util.beehotelunit');

    $data['node'] = $beehotelunit->getVariationNode($entity);
    $data['nid'] = $data['node']->Id();

    $data['season'] = \Drupal::service('beehotel_pricealterator.prealter')->season($data);
    $data = \Drupal::service('beehotel_pricealterator.alter')->alter($data);
  }

}
